@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 from abc import ABCMeta
 
-from pathlib import Path
-
 from fastapi import Response
 from fastapi.responses import JSONResponse
 from fastapi.templating import Jinja2Templates
@@ -16,8 +14,7 @@ import re
 import connegp
 from .data import MEDIATYPE_NAMES, RDF_MEDIATYPES
 
-templates_dir = Path(__file__).parent.parent / "pyldapi" / "templates"
-templates = Jinja2Templates(directory=str(templates_dir))
+templates = Jinja2Templates(directory="templates")
 
 
 class Renderer(object, metaclass=ABCMeta):
@@ -358,7 +355,7 @@ class Renderer(object, metaclass=ABCMeta):
             for mediatype in profile.mediatypes:
                 # set the rel="self" just for this profile & mediatype
                 if mediatype != '_internal':
-                    if token == self.default_profile_token and mediatype == self.profiles[self.profile].default_mediatype:
+                    if token == self.profile and mediatype == self.profiles[self.profile].default_mediatype:
                         rel = 'self'
                     else:
                         rel = 'alternate'
@@ -443,10 +440,9 @@ class Renderer(object, metaclass=ABCMeta):
         )
 
     def _render_alt_profile_html(
-            self,
-            alt_template: str = "alt.html",
-            additional_alt_template_context=None,
-            alt_template_context_replace=False
+        self,
+        additional_alt_template_context=None,
+        alt_template_context_replace=False
     ):
         """Renders the Alternates Profile in HTML
 
@@ -490,7 +486,7 @@ class Renderer(object, metaclass=ABCMeta):
             else:
                 _template_context.update(additional_alt_template_context)
 
-        return templates.TemplateResponse(alt_template,
+        return templates.TemplateResponse("alt.html",
                                           context=_template_context,
                                           headers=self.headers)
 
@@ -509,23 +505,33 @@ class Renderer(object, metaclass=ABCMeta):
             headers=self.headers
         )
 
-    def _render_alt_profile(self):
+    def _render_alt_profile(
+        self,
+        additional_alt_template_context=None,
+        alt_template_context_replace=False
+    ):
         """
         Return a Flask Response object depending on the value assigned to :code:`self.mediatype`.
 
         :return: A Flask Response object
         :rtype: :class:`flask.Response`
         """
-        if self.mediatype == '_internal':
-            return self
         if self.mediatype == 'text/html':
-            return self._render_alt_profile_html()
+            return self._render_alt_profile_html(
+                additional_alt_template_context,
+                alt_template_context_replace
+            )
         elif self.mediatype in RDF_MEDIATYPES:
             return self._render_alt_profile_rdf()
         else:  # application/json
             return self._render_alt_profile_json()
 
-    def render(self):
+    def render(
+        self,
+        alt_template: str = "alt.html",
+        additional_alt_template_context=None,
+        alt_template_context_replace=False
+    ):
         """
         Use the received profile and mediatype to create a response back to the client.
 
@@ -542,7 +548,10 @@ class Renderer(object, metaclass=ABCMeta):
         if self.vf_error is not None:
             return Response(self.vf_error, status=400, media_type='text/plain')
         elif self.profile == 'alt' or self.profile == 'alternates':
-            return self._render_alt_profile()
+            return self._render_alt_profile(
+                additional_alt_template_context,
+                alt_template_context_replace
+            )
         return None
 
     # end making response content
